@@ -654,11 +654,7 @@ static void cleanup_header_callback(void *context, int header_class,
 		argv_add(state->auto_hdrs, vstring_str(header_buf), ARGV_END);
 	}
 	if (hdr_opts->type == HDR_TLS_REQUIRED && var_tls_required_enable) {
-	    char   *cp = vstring_str(header_buf) + strlen(hdr_opts->name) + 1;
-
-	    while (ISSPACE(*cp))
-		cp++;
-	    if (strcasecmp(cp, "no") == 0)
+	    if (strcasecmp(hdrval, "no") == 0)
 		state->sendopts |= SOPT_REQUIRETLS_HEADER;
 	    else
 		msg_warn("ignoring malformed header: '%.100s'",
@@ -666,11 +662,7 @@ static void cleanup_header_callback(void *context, int header_class,
 	}
 	if (hdr_opts->type == HDR_REQTLS_ESMTP && var_reqtls_esmtp_hdr
 	    && var_reqtls_enable) {
-	    char   *cp = vstring_str(header_buf) + strlen(hdr_opts->name) + 1;
-
-	    while (ISSPACE(*cp))
-		cp++;
-	    if (strcasecmp(cp, "yes") == 0) {
+	    if (strcasecmp(hdrval, "yes") == 0) {
 		state->sendopts |= SOPT_REQUIRETLS_ESMTP;
 		state->reqtls_esmtp_hdr_seen += 1;
 	    }
